@@ -2,10 +2,10 @@
 
 __author__ = """Daniel Kramer"""
 __email__ = 'drk98@nau.edu'
-__version__ = '0.3.0'
+__version__ = '0.3.2'
 
 
 from .hg import bowellCalcAbsMag, calcPhaseCurve
 from .reducedMag import calcReducedMag
 from .useAstroQuery import HorAbsMags
-from .bestFit import BestFit
\ No newline at end of file
+from .bestFit import BestFit, HGResult
\ No newline at end of file
